<!-- warning: Please don't edit this file. It was automatically generated. -->

# winui3-Microsoft.Security.Authentication.OAuth

Windows Runtime (WinRT) APIs for for the `winui3-Microsoft.Security.Authentication.OAuth` namespace.

This package provides the `winui3.microsoft.security.authentication.oauth` module.
